Summary:       Password checking library and dictionaries
Name:          cracklib
Version:       2.9.11
Release:       4%{?dist}
License:       LGPLv2+
URL:           https://github.com/cracklib/cracklib
Source0:       %{url}/releases/download/v%{version}/cracklib-%{version}.tar.gz
Source1:       %{url}/releases/download/v%{version}/cracklib-words-%{version}.gz
#man pages
Source2:       http://archive.debian.org/debian/pool/main/c/cracklib2/cracklib2_2.9.2-1.debian.tar.xz

BuildRequires: autoconf automake libtool
BuildRequires: zlib-devel
Requires:      gzip

%description
CrackLib is a library containing a C function (well, lots of functions
really, but you only need to use one of them) which may be used in a
"passwd"-like program.
The idea is simple: try to prevent users from choosing passwords that
could be guessed by "Crack" by filtering them out, at source.
CrackLib finds potential passwords quickly, by using an index file to
access dictionary words, and by keeping a table to assist binary
searching.
CrackLib's dictionary is modified-DAWG compressed with a chunksize of 16
words and then the index file is built, with one entry per chunk.
CrackLib makes literally hundreds of tests to determine whether you've
chosen a bad password.
* It tries to generate words from your username and gecos entry to tries
to match them against what you've chosen.
* It checks for simplistic patterns.
* It then tries to reverse-engineer your password into a dictionary
word, and searches for it in your dictionary.
- after all that, it's PROBABLY a safe(-ish) password.


%package devel
Summary:       Development files for cracklib
Requires:      %{name} = %{version}-%{release}

%description devel
Header files and libraries for developing applications which use cracklib.


%package dicts
Summary:       The standard CrackLib dictionaries
Requires:      cracklib = %{version}-%{release}

%description dicts
The cracklib-dicts package includes the CrackLib dictionaries, which is normally put in
/usr/share/dict/words. Cracklib-dicts also contains the utilities necessary for
the creation of new dictionaries.


%prep
%autosetup -p1 -a 2

mkdir cracklib-dicts
cp -fv %{SOURCE1} cracklib-dicts/


%build
AUTOPOINT=true autoreconf -fi
sed -i 's|util/cracklib-check <|util/cracklib-check $(DESTDIR)/$(DEFAULT_CRACKLIB_DICT) <|' Makefile.in
%configure --with-pic --disable-static 
%make_build


%install
%make_install
rm -f %{buildroot}%{_libdir}/python*/site-packages/_cracklib*.*a
rm -f %{buildroot}%{_libdir}/libcrack.la

chmod +x util/cracklib-format
./util/cracklib-format cracklib-dicts/* | ./util/cracklib-packer %{buildroot}%{_datadir}/cracklib/pw_dict
./util/cracklib-format %{buildroot}%{_datadir}/cracklib/cracklib-small | \
./util/cracklib-packer %{buildroot}%{_datadir}/cracklib/cracklib-small
rm -f %{buildroot}%{_datadir}/cracklib/cracklib-small

sed "s|/usr/lib/cracklib_dict|%{_datadir}/cracklib/pw_dict|g" lib/crack.h > %{buildroot}%{_includedir}/crack.h

ln -s cracklib-format %{buildroot}%{_sbindir}/mkdict
ln -sf %{_datadir}/cracklib/pw_dict.hwm %{buildroot}%{_libdir}/cracklib_dict.hwm
ln -sf %{_datadir}/cracklib/pw_dict.pwd %{buildroot}%{_libdir}/cracklib_dict.pwd
ln -sf %{_datadir}/cracklib/pw_dict.pwi %{buildroot}%{_libdir}/cracklib_dict.pwi

mkdir -p %{buildroot}%{_mandir}/man{3,8}
install -p -m644 debian/*.3 %{buildroot}%{_mandir}/man3/
install -p -m644 debian/*.8 %{buildroot}%{_mandir}/man8/
echo ".so man8/cracklib-format.8" > %{buildroot}%{_mandir}/man8/cracklib-packer.8
echo ".so man8/cracklib-format.8" > %{buildroot}%{_mandir}/man8/cracklib-unpacker.8

%find_lang %{name}


%check
make test


%files -f %{name}.lang
%license COPYING.LIB
%doc README README-WORDS NEWS README-LICENSE AUTHORS
%{_libdir}/libcrack.so.*
%{_sbindir}/*cracklib*
%dir %{_datadir}/cracklib
%{_datadir}/cracklib/cracklib.magic
%{_mandir}/man8/*

%files devel
%{_includedir}/*
%{_libdir}/libcrack.so
%{_mandir}/man3/*

%files dicts
%{_sbindir}/mkdict
%{_libdir}/cracklib_dict.*
%{_datadir}/cracklib/pw_dict.*
%{_datadir}/cracklib/cracklib-small.*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.11-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.7-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.9.7-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Jul 19 2022 rockerzhu <rockerzhu@tencent.com> - 2.9.7-1
- Initial build
